@@ -5,7 +5,7 @@
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 /// Basic ISO box structure.
-pub struct Mp4BoxHeader {
+pub struct BoxHeader {
     /// Four character box type
 pub name: u32,
     /// Size of the box in bytes
@@ -15,7 +15,7 @@ pub offset: u64,
 }
 
 /// File type box 'ftyp'.
-pub struct Mp4FileTypeBox {
+pub struct FileTypeBox {
     name: u32,
     size: u64,
     major_brand: u32,
@@ -28,7 +28,7 @@ use byteorder::{BigEndian, ReadBytesExt};
 use std::io::{Result, Seek, SeekFrom};
 
 /// Parse a box out of a data buffer.
-pub fn read_box_header<T: ReadBytesExt>(src: &mut T) -> Option<Mp4BoxHeader> {
+pub fn read_box_header<T: ReadBytesExt>(src: &mut T) -> Option<BoxHeader> {
     let tmp_size = src.read_u32::<BigEndian>().unwrap();
     let name = src.read_u32::<BigEndian>().unwrap();
     let size = match tmp_size {
@@ -44,7 +44,7 @@ pub fn read_box_header<T: ReadBytesExt>(src: &mut T) -> Option<Mp4BoxHeader> {
         _ => 4 + 4,
     };
     assert!(offset <= size);
-    Some(Mp4BoxHeader{
+    Some(BoxHeader{
         name: name,
         size: size,
         offset: offset,
@@ -52,16 +52,16 @@ pub fn read_box_header<T: ReadBytesExt>(src: &mut T) -> Option<Mp4BoxHeader> {
 }
 
 /// Skip over the contents of a box.
-pub fn skip_box_content<T: ReadBytesExt + std::io::Seek>
-  (src: &mut T, header: &Mp4BoxHeader)
+pub fn skip_box_content<T: ReadBytesExt + Seek>
+  (src: &mut T, header: &BoxHeader)
   -> std::io::Result<u64>
 {
     src.seek(SeekFrom::Current((header.size - header.offset) as i64))
 }
 
 /// Parse an ftype box.
-pub fn read_ftyp<T: ReadBytesExt>(src: &mut T) -> Option<Mp4FileTypeBox> {
-    let head = read_box_header(src).unwrap();
+pub fn read_ftyp<T: ReadBytesExt>(src: &mut T, head: &BoxHeader)
+  -> Option<FileTypeBox> {
     let major = src.read_u32::<BigEndian>().unwrap();
     let minor = src.read_u32::<BigEndian>().unwrap();
     let brand_count = (head.size - 8 - 8) /4;
@@ -69,7 +69,7 @@ pub fn read_ftyp<T: ReadBytesExt>(src: &mut T) -> Option<Mp4FileTypeBox> {
     for _ in 0..brand_count {
         brands.push(src.read_u32::<BigEndian>().unwrap());
     }
-    Some(Mp4FileTypeBox{
+    Some(FileTypeBox{
         name: head.name,
         size: head.size,
         major_brand: major,
@@ -78,29 +78,29 @@ pub fn read_ftyp<T: ReadBytesExt>(src: &mut T) -> Option<Mp4FileTypeBox> {
     })
 }
 
-/// Split a u32 box type into a [u8].
-fn u32_to_vec(x: u32) -> Vec<u8> {
-    vec!((x >> 24 & 0xffu32) as u8,
-         (x >> 16 & 0xffu32) as u8,
-         (x >>  8 & 0xffu32) as u8,
-         (x & 0xffu32) as u8)
+/// Convert the iso box type or other 4-character value to a string.
+pub fn fourcc_to_string(name: u32) -> String {
+    let u32_to_vec = |u| {
+        vec!((u >> 24 & 0xffu32) as u8,
+             (u >> 16 & 0xffu32) as u8,
+             (u >>  8 & 0xffu32) as u8,
+             (u & 0xffu32) as u8)
+    };
+    let name_bytes = u32_to_vec(name);
+    String::from_utf8_lossy(&name_bytes).into_owned()
 }
 
 use std::fmt;
-impl fmt::Display for Mp4BoxHeader {
+impl fmt::Display for BoxHeader {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        let name_bytes = u32_to_vec(self.name);
-        let name = String::from_utf8_lossy(&name_bytes);
-        write!(f, "'{}' {} bytes", name, self.size)
+        write!(f, "'{}' {} bytes", fourcc_to_string(self.name), self.size)
     }
 }
 
-impl fmt::Display for Mp4FileTypeBox {
+impl fmt::Display for FileTypeBox {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        let name_bytes = u32_to_vec(self.name);
-        let name = String::from_utf8_lossy(&name_bytes);
-        let brand_bytes = u32_to_vec(self.major_brand);
-        let brand = String::from_utf8_lossy(&brand_bytes);
+        let name = fourcc_to_string(self.name);
+        let brand = fourcc_to_string(self.major_brand);
         write!(f, "'{}' {} bytes '{}' v{}", name, self.size,
             brand, self.minor_version)
     }
@@ -147,7 +147,8 @@ fn test_read_ftyp() {
     assert_eq!(test.len(), 24);
 
     let mut stream = Cursor::new(test);
-    let parsed = read_ftyp(&mut stream).unwrap();
+    let header = read_box_header(&mut stream).unwrap();
+    let parsed = read_ftyp(&mut stream, &header).unwrap();
     assert_eq!(parsed.name, 1718909296);
     assert_eq!(parsed.size, 24);
     assert_eq!(parsed.major_brand, 1836069938);
